<?php

namespace App\Http\Controllers;

use App\Models\Banners;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
Use RealRashid\SweetAlert\Facades\Alert;

class BannersController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $data['banner'] = Banners::all();
        return view('admin.banners_managment.index', $data);

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.banners_managment.create');

    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $validitor = Validator::make($request->all(), [
            'picture' => 'sometimes|image'
        ]);

        if ($validitor->fails()) {
            alert()->error('Opps...','There is some issue with input');
            return Redirect::route('add-banners')->withErrors($validitor)->withInput();
        }

        $banner = new Banners();
        $banner->title = $request->title;
        $banner->description = $request->description;

        $banner->title_ar = $request->title_ar;
        $banner->description_ar = $request->description_ar;
        $banner->tag_title = $request->tag_title;
        $banner->tag_title_ar = $request->tag_title_ar;

        if($request->hasFile('image')){

            $image = $request->file('image');
            $image_name =  time().$image->getClientOriginalName();
            $path = $request->file('image')->move('banner', $image_name);
             $banner->picture = 'banner/'.$image_name;
        }

        $banner->save();
        Alert::success('Success ', 'Banner has been Created');

        return Redirect::route('show-banners');
    }


    /**
     * Display the specified resource.
     *
     * @param  \App\Models\BannersController  $bannersController
     * @return \Illuminate\Http\Response
     */
    public function show(BannersController $bannersController)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\BannersController  $bannersController
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data['id'] = $id;
        $data['banner'] = Banners::find($id); // Eloquent
        return view('/admin/banners_managment.update', $data);
    }
    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\BannersController  $bannersController
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $validitor = Validator::make($request->all(), [

            'picture' => 'sometimes|image'

        ]);


        if ($validitor->fails()) {
            alert()->error('Opps...','There is some issue with input');

            return Redirect::route('edit-banners',$id)->withErrors($validitor)->withInput();
        }


        $banner = Banners::find($id);
        $banner->title = $request->title;
        $banner->description = $request->description;
        $banner->title_ar = $request->title_ar;
        $banner->description_ar = $request->description_ar;
        $banner->tag_title = $request->tag_title;
        $banner->tag_title_ar = $request->tag_title_ar;

        if($request->hasFile('image')){
            $image = $request->file('image');
            $image_name =  time().$image->getClientOriginalName();
            $path = $request->file('image')->move('banner', $image_name);
            $banner->picture = 'banner/'.$image_name;
        }

        $banner->save();
        Alert::success('Success ', 'Banner has been Updated');

        return Redirect::route('show-banners');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\BannersController  $bannersController
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
      $banner =  Banners::find($id);
      $banner->delete();
      return back();
    }
}
