<?php

namespace App\Http\Controllers;

use App\Models\Clients;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
Use RealRashid\SweetAlert\Facades\Alert;


class ClientsController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {   
        $data['gallery'] = Clients::all();
        return view('admin.clients_management.index', $data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.clients_management.create');

    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $validitor = Validator::make($request->all(), [
            'picture' => 'sometimes|image'
        ]);


        if ($validitor->fails()) {
            alert()->error('Opps...','There is some issue with input');
            return Redirect::route('add-client')->withErrors($validitor)->withInput();
        }


        $gallery = new Clients();
        $gallery->title = $request->title;
        $gallery->title_ar = $request->title_ar;
        //$gallery->description_ar = $request->description_ar;
        $gallery->priority = $request->priority;
        //$gallery->description = $request->description;
        
        if($request->hasFile('image')){
            $image = $request->file('image');
            $image_name =  time().$image->getClientOriginalName();
            $path = $request->file('image')->move('image_set', $image_name);
            $gallery->picture = 'image_set/'.$image_name;
        }

        $gallery->save();
        Alert::success('Success ', 'Client has been Created');

        return Redirect::route('show-client');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Clients  $Clients
     * @return \Illuminate\Http\Response
     */
    public function show(Clients $clients)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Clients  $Clients
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data['gallery'] = Clients::find($id); // Eloquent
        return view('/admin/clients_management.update', $data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Clients  $Clients
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $validitor = Validator::make($request->all(), [
            'picture' => 'sometimes|image'
        ]);


        if ($validitor->fails()) {
            alert()->error('Opps...','There is some issue with input');

            return Redirect::route('edit-gallery',$id)->withErrors($validitor)->withInput();
        }


        $gallery = Clients::find($id);
        $gallery->title = $request->title;
        $gallery->title_ar = $request->title_ar;
        //$gallery->description_ar = $request->description_ar;
        $gallery->priority = $request->priority;
       // $gallery->description = $request->description;               
        if($request->hasFile('image')){

            $image = $request->file('image');
            $image_name =  time().$image->getClientOriginalName();
            $path = $request->file('image')->move('image_set', $image_name);
             $gallery->picture = 'image_set/'.$image_name;
        }

        $gallery->save();
        Alert::success('Success ', 'Client has been Updated');

        return Redirect::route('show-client');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Clients  $Clients
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
      $gallery =  Clients::find($id);
      $gallery->delete();
      return back();
    }
}
