<?php

namespace App\Http\Controllers;

use App\Models\Galleries;
use App\Models\Project;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
Use RealRashid\SweetAlert\Facades\Alert;


class GalleriesController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $data['gallery'] = Galleries::all();
        return view('admin.gallery_managment.index', $data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $data['project_cat_list'] = Project::all();
        return view('admin.gallery_managment.create', $data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $validitor = Validator::make($request->all(), [
            'picture' => 'sometimes|image'
        ]);


        if ($validitor->fails()) {
            alert()->error('Opps...','There is some issue with input');
            return Redirect::route('add-gallery')->withErrors($validitor)->withInput();
        }


        $gallery = new Galleries();
        $gallery->title = $request->title;
        $gallery->title_ar = $request->title_ar;
        //$gallery->description_ar = $request->description_ar;
        $gallery->priority = $request->priority;
        // $gallery->d_year = $request->d_year;
        // $gallery->project_id = $request->project_id;
        //$gallery->description = $request->description;
        
        if($request->hasFile('image')){
            $image = $request->file('image');
            $image_name =  time().$image->getClientOriginalName();
            $path = $request->file('image')->move('image_set', $image_name);
            $gallery->picture = 'image_set/'.$image_name;
        }

        $gallery->save();
        Alert::success('Success ', 'Gallery has been Created');

        return Redirect::route('show-gallery');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Galleries  $galleries
     * @return \Illuminate\Http\Response
     */
    public function show(Galleries $galleries)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Galleries  $galleries
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data['gallery'] = Galleries::find($id); // Eloquent
        $data['project_cat_list'] = Project::all();        
        return view('/admin/gallery_managment.update', $data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Galleries  $galleries
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $validitor = Validator::make($request->all(), [
            'picture' => 'sometimes|image'
        ]);


        if ($validitor->fails()) {
            alert()->error('Opps...','There is some issue with input');

            return Redirect::route('edit-gallery',$id)->withErrors($validitor)->withInput();
        }


        $gallery = Galleries::find($id);
        $gallery->title = $request->title;
        $gallery->title_ar = $request->title_ar;
        //$gallery->description_ar = $request->description_ar;
        $gallery->priority = $request->priority;
        // $gallery->d_year = $request->d_year;        
        // $gallery->project_id = $request->project_id;
       // $gallery->description = $request->description;               
        if($request->hasFile('image')){

            $image = $request->file('image');
            $image_name =  time().$image->getClientOriginalName();
            $path = $request->file('image')->move('image_set', $image_name);
             $gallery->picture = 'image_set/'.$image_name;
        }

        $gallery->save();
        Alert::success('Success ', 'Gallery has been Updated');

        return Redirect::route('show-gallery');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Galleries  $galleries
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
      $gallery =  Galleries::find($id);
      $gallery->delete();
      return back();
    }
}
