<?php

namespace App\Http\Controllers;

use App\Models\Images;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
Use RealRashid\SweetAlert\Facades\Alert;

class ImagesController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $data['images'] = Images::all();
        return view('admin.imagesettings_managment.index', $data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.imagesettings_managment.create');

    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $validitor = Validator::make($request->all(), [

            'title' => 'required|max:255',
            'picture' => 'sometimes|image'


        ]);


        if ($validitor->fails()) {
            alert()->error('Opps...','There is some issue with input');

            return Redirect::route('add-images')->withErrors($validitor)->withInput();
        }


        $image_settings = new Images();
        $image_settings->title = $request->title;
        if($request->hasFile('image')){

            $image = $request->file('image');
            $image_name =  time().$image->getClientOriginalName();
            $path = $request->file('image')->move('image_set', $image_name);
             $image_settings->picture = 'image_set/'.$image_name;
        }

        $image_settings->save();
        Alert::success('Success ', 'Image has been Created');

        return Redirect::route('show-images');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Images  $images
     * @return \Illuminate\Http\Response
     */
    public function show(Images $images)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Images  $images
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data['images'] = Images::find($id); // Eloquent
        return view('/admin/imagesettings_managment.update', $data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Images  $images
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request,$id)
    {
        $validitor = Validator::make($request->all(), [

            'title' => 'required|max:255',
            'picture' => 'sometimes|image'


        ]);


        if ($validitor->fails()) {
            alert()->error('Opps...','There is some issue with input');

            return Redirect::route('edit-images',$id)->withErrors($validitor)->withInput();
        }


        $image_settings =  Images::find($id);
        $image_settings->title = $request->title;
        if($request->hasFile('image')){

            $image = $request->file('image');
            $image_name =  time().$image->getClientOriginalName();
            $path = $request->file('image')->move('image_set', $image_name);
             $image_settings->picture = 'image_set/'.$image_name;
        }

        $image_settings->save();
        Alert::success('Success ', 'Image has been Updated');

        return Redirect::route('show-images');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Images  $images
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
      $images =  Images::find($id);
      $images->delete();
      return back();
    }
}
