<?php

namespace App\Http\Controllers;

use App\Models\Project;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
Use RealRashid\SweetAlert\Facades\Alert;
use File;

class ProjectController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
      $data['project_cat_list'] = Project::all();
      return view('admin.projects.index', $data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.projects.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
      $validitor = Validator::make($request->all(), [
          'title' => 'required|min:2|max:255'
      ]);


      if ($validitor->fails()) {
          alert()->error('Opps...','There is some issue with input');
          return Redirect::route('add-projects')->withErrors($validitor)->withInput();
      }


      $project = new Project();

      if($request->hasFile('image')){
        $image = $request->file('image');
        $image_name =  time().$image->getClientOriginalName();
        $path = $request->file('image')->move('project_img', $image_name);
        $project->picture = 'project_img/'.$image_name;
      }
      $project->description = $request->description;
      $project->description_ar = $request->description_ar;  

      $project->title = $request->title;
      $project->title_ar = $request->title_ar;
      $project->priority = $request->priority;
      $project->save();

      Alert::success('Success ', 'Project Category has been Created');

      return Redirect::route('show-projects');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Project  $project
     * @return \Illuminate\Http\Response
     */
    public function show(Project $project)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Project  $project
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
      $data['project'] = Project::find($id); // Eloquent
      return view('/admin/projects.update', $data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Project  $project
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
      $validitor = Validator::make($request->all(), [
          'title' => 'required|min:2|max:255',
      ]);


      if ($validitor->fails()) {
          alert()->error('Opps...','There is some issue with input');
          return Redirect::route('add-projects')->withErrors($validitor)->withInput();
      }


      $project = Project::find($id);
      if($request->hasFile('image')){
        $image = $request->file('image');
        $image_name =  time().$image->getClientOriginalName();
        $path = $request->file('image')->move('project_img', $image_name);
        $project->picture = 'project_img/'.$image_name;
      }
      $project->description = $request->description;
      $project->description_ar = $request->description_ar; 
            
      $project->title = $request->title;
      $project->title_ar = $request->title_ar;
      $project->priority = $request->priority;
      $project->save();

      Alert::success('Success ', 'Project Category has been Updated successfully');

      return Redirect::route('show-projects');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Project  $project
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
      $project =  Project::find($id);
      $project->delete();
      return back();
    }
}
