<?php

namespace App\Http\Controllers;
use App\Models\Project;
use App\Models\Projectdetails;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
Use RealRashid\SweetAlert\Facades\Alert;
use File;

class ProjectdetailsController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
     public function index($id)
     {
         $data['id']=$id;
         $data['project_details'] = Projectdetails::where('project_id',$id)->get();
         return view('admin.project_details.index', $data);
     }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
     public function create($id)
     {
         $data['id']=$id;
         return view('admin.project_details.create',$data);
     }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
     public function store(Request $request,$id)
     {
         $validitor = Validator::make($request->all(), [
             'picture' => 'sometimes|image'
         ]);

         if ($validitor->fails()) {
             alert()->error('Opps...','There is some issue with input');
             return Redirect::route('add-project-details',$id)->withErrors($validitor)->withInput();
         }

         $project_details = new Projectdetails();

         if($request->hasFile('image')){
             $image = $request->file('image');
             $image_name =  time().$image->getClientOriginalName();
             $path = $request->file('image')->move('project_img', $image_name);
             $project_details->picture = 'project_img/'.$image_name;
         }

         $project_details->title = $request->title;
         $project_details->title_ar = $request->title_ar;
        // $project_details->title2 = $request->title2;
        // $project_details->title2_ar = $request->title2_ar; 
         $project_details->description = $request->description;
         $project_details->description_ar = $request->description_ar;                  
         $project_details->priority = $request->priority;
         $project_details->client = $request->client;
         $project_details->client_ar = $request->client_ar;         
         $project_details->project_id = $id;

         $project_details->save();
         Alert::success('Success ', 'Project Details has been Created');

         return Redirect::route('show-project-details',$id);
     }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Projectdetails  $projectdetails
     * @return \Illuminate\Http\Response
     */
    public function show(Projectdetails $projectdetails)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Projectdetails  $projectdetails
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
      $data['project_details']  = Projectdetails::find($id);
      $data['id']  = $id;
      return view('/admin/project_details.update', $data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Projectdetails  $projectdetails
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
      $validitor = Validator::make($request->all(), [
          'picture' => 'sometimes|image'
      ]);

      $project_details = Projectdetails::find($id);

      if ($validitor->fails()) {
        alert()->error('Opps...','There is some issue with input');
        return Redirect::route('update-project-details', $project_details->project_id)->withErrors($validitor)->withInput();
    }

      if($request->hasFile('image')){

          $image = $request->file('image');
          $image_name =  time().$image->getClientOriginalName();
          $path = $request->file('image')->move('project_img', $image_name);
           $project_details->picture = 'project_img/'.$image_name;
      }

      $project_details->title = $request->title;
      $project_details->title_ar = $request->title_ar;
      //$project_details->title2 = $request->title2;
      //$project_details->title2_ar = $request->title2_ar; 
      $project_details->description = $request->description;
      $project_details->description_ar = $request->description_ar;       
      $project_details->priority = $request->priority;
      $project_details->client = $request->client;
      $project_details->client_ar = $request->client_ar;         

      $project_details->save();
      Alert::success('Success ', 'Project Details has been Created');

      return Redirect::route('show-project-details',$id);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Projectdetails  $projectdetails
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $projectDetail =  Projectdetails::find($id);
        $projectDetail->delete();
        return back();
    }
}
