<?php

namespace App\Http\Controllers;

use App\Models\Service;
use App\Models\Servicedetails;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
Use RealRashid\SweetAlert\Facades\Alert;
use File;
class ServicedetailsController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index($id)
    {
        $data['id']=$id;
        $data['service_details'] = Servicedetails::where('service_id',$id)->get();
        return view('admin.service_details.index', $data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create($id)
    {
        $data['id']=$id;
        return view('admin.service_details.create',$data);

    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request,$id)
    {
        $validitor = Validator::make($request->all(), [
            'title' => 'required|max:255',
            'picture' => 'sometimes|image'
        ]);


        if ($validitor->fails()) {
            alert()->error('Opps...', 'There is some issue with input');
            return Redirect::route('add-service-details',$id)->withErrors($validitor)->withInput();
        }

        $service_details = new Servicedetails();
        if($request->hasFile('image')){
            $image = $request->file('image');
            $image_name =  time().$image->getClientOriginalName();
            $path = $request->file('image')->move('service_img', $image_name);
            $service_details->picture = 'service_img/'.$image_name;
        }
        // if($request->hasFile('icon')){
        //     $image = $request->file('icon');
        //     $image_name =  time().$image->getClientOriginalName();
        //     $path = $request->file('icon')->move('service_img', $image_name);
        //     $service_details->icon = 'service_img/'.$image_name;
        // }

        $service_details->title = $request->title;
        $service_details->title_ar = $request->title_ar;
        $service_details->description_ar = $request->description_ar;

        $service_details->priority = $request->priority;
        $service_details->description = $request->description;
        $service_details->service_id = $id;
        $service_details->icon = $request->icon;


        $service_details->save();
        Alert::success('Success ', 'Service Details has been Created');

        return Redirect::route('show-service-details',$id);
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Servicedetails  $servicedetails
     * @return \Illuminate\Http\Response
     */
    public function show(Servicedetails $servicedetails)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Servicedetails  $servicedetails
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data['service_details']  = Servicedetails::find($id);
        $data['id']  = $id;
        return view('/admin/service_details.update', $data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Servicedetails  $servicedetails
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $validitor = Validator::make($request->all(), [
            'title' => 'required|max:255',
            'picture' => 'sometimes|image'
        ]);


        if ($validitor->fails()) {
            alert()->error('Opps...','There is some issue with input');
            return Redirect::route('edit-service-details',$id)->withErrors($validitor)->withInput();
        }


        $service_details = Servicedetails::find($id);

        if($request->hasFile('image')){
            $image = $request->file('image');
            $image_name =  time().$image->getClientOriginalName();
            $path = $request->file('image')->move('service_img', $image_name);
            $service_details->picture = 'service_img/'.$image_name;
        }
        if($request->hasFile('icon')){
            $image = $request->file('icon');
            $image_name =  time().$image->getClientOriginalName();
            $path = $request->file('icon')->move('service_img', $image_name);
            $service_details->icon = 'service_img/'.$image_name;
        }
        
        $service_details->title = $request->title;
        $service_details->title_ar = $request->title_ar;
        $service_details->description_ar = $request->description_ar;
        $service_details->description = $request->description;
        $service_details->priority = $request->priority;
        $service_details->icon = $request->icon;        


        $service_details->save();
        Alert::success('Success ', 'Service Details has been Updated');

        return Redirect::route('show-service-details',$service_details->service_id);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Servicedetails  $servicedetails
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
      $service_details =  Servicedetails::find($id);
      $service_details->delete();
      return back();
    }

    public function delete_file($id)
    {


        $filedelete = Servicedetails::findOrFail($id);

        $image_path = $filedelete->picture;

        if (File::exists(public_path($image_path))) {

            File::delete(public_path($image_path));
            $filedelete->picture = "";
            $filedelete->save();

            return back();
        } else {

            dd('File does not exists.');
        }

    }
}
